@@ -35,8 +35,7 @@ except ImportError:
     BASEHOOK_PATCH_PATH = "airflow.hooks.base.BaseHook"
 from airflow import DAG
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
-from airflow.models import Connection, DagRun, TaskInstance as TI
-from airflow.models.serialized_dag import SerializedDagModel
+from airflow.models import Connection
 from airflow.providers.common.sql.hooks.handlers import fetch_all_handler
 from airflow.providers.common.sql.operators.sql import (
     BaseSQLOperator,
@@ -52,19 +51,17 @@ from airflow.providers.common.sql.operators.sql import (
 from airflow.providers.postgres.hooks.postgres import PostgresHook
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.utils import timezone  # type: ignore[attr-defined]
-from airflow.utils.session import create_session
 from airflow.utils.state import State
 from airflow.utils.types import DagRunType
 
+from tests_common.test_utils.dag import sync_dag_to_db
+from tests_common.test_utils.db import clear_db_dag_bundles, clear_db_dags, clear_db_runs, clear_db_xcom
 from tests_common.test_utils.markers import skip_if_force_lowest_dependencies_marker
 from tests_common.test_utils.providers import get_provider_min_airflow_version
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_1, AIRFLOW_V_3_0_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
-    from airflow.models.xcom import XComModel as XCom
     from airflow.utils.types import DagRunTriggeredByType
-else:
-    from airflow.models.xcom import XCom  # type: ignore[no-redef]
 
 pytestmark = pytest.mark.db_test
 
@@ -1088,14 +1085,21 @@ class TestSqlBranch:
     Test for SQL Branch Operator
     """
 
+    @staticmethod
+    def clear_db():
+        clear_db_dags()
+        clear_db_runs()
+        clear_db_xcom()
+        if AIRFLOW_V_3_0_PLUS:
+            clear_db_dag_bundles()
+
     @classmethod
     def setup_class(cls):
-        with create_session() as session:
-            session.query(DagRun).delete()
-            session.query(TI).delete()
-            session.query(XCom).delete()
+        cls.clear_db()
 
     def setup_method(self):
+        self.clear_db()
+
         self.dag = DAG(
             "sql_branch_operator_test",
             default_args={"owner": "airflow", "start_date": DEFAULT_DATE},
@@ -1105,8 +1109,9 @@ class TestSqlBranch:
         self.branch_2 = EmptyOperator(task_id="branch_2", dag=self.dag)
         self.branch_3 = None
         if AIRFLOW_V_3_0_PLUS:
-            self.dag.sync_to_db()
-            SerializedDagModel.write_dag(self.dag, bundle_name="testing")
+            self.scheduler_dag = sync_dag_to_db(self.dag)
+        else:
+            self.scheduler_dag = self.dag
 
     def get_ti(self, task_id, dr=None):
         if dr is None:
@@ -1118,7 +1123,7 @@ class TestSqlBranch:
                 }
             else:
                 dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-            dr = self.dag.create_dagrun(
+            dr = self.scheduler_dag.create_dagrun(
                 run_id=f"manual__{timezone.utcnow().isoformat()}",
                 run_type=DagRunType.MANUAL,
                 start_date=timezone.utcnow(),
@@ -1133,10 +1138,7 @@ class TestSqlBranch:
         return ti
 
     def teardown_method(self):
-        with create_session() as session:
-            session.query(DagRun).delete()
-            session.query(TI).delete()
-            session.query(XCom).delete()
+        self.clear_db()
 
     @pytest.fixture
     def branch_op(self):
@@ -1149,8 +1151,7 @@ class TestSqlBranch:
             dag=self.dag,
         )
         if AIRFLOW_V_3_0_PLUS:
-            self.dag.sync_to_db()
-            SerializedDagModel.write_dag(self.dag, bundle_name="testing")
+            self.scheduler_dag = sync_dag_to_db(self.dag)
         return branch_op
 
     def test_unsupported_conn_type(self):
@@ -1163,11 +1164,10 @@ class TestSqlBranch:
             follow_task_ids_if_false=["branch_2"],
             dag=self.dag,
         )
-
         with pytest.raises(AirflowException):
             op.execute({})
 
-    def test_invalid_conn(self):
+    def test_invalid_conn(self, sdk_connection_not_found):
         """Check if BranchSQLOperator throws an exception for invalid connection"""
         op = BranchSQLOperator(
             task_id="make_choice",
@@ -1177,11 +1177,10 @@ class TestSqlBranch:
             follow_task_ids_if_false=["branch_2"],
             dag=self.dag,
         )
-
         with pytest.raises(AirflowException):
             op.execute({})
 
-    def test_invalid_follow_task_true(self):
+    def test_invalid_follow_task_true(self, sdk_connection_not_found):
         """Check if BranchSQLOperator throws an exception for invalid connection"""
         op = BranchSQLOperator(
             task_id="make_choice",
@@ -1194,7 +1193,7 @@ class TestSqlBranch:
         with pytest.raises(AirflowException):
             op.execute({})
 
-    def test_invalid_follow_task_false(self):
+    def test_invalid_follow_task_false(self, sdk_connection_not_found):
         """Check if BranchSQLOperator throws an exception for invalid connection"""
         op = BranchSQLOperator(
             task_id="make_choice",
@@ -1224,6 +1223,8 @@ class TestSqlBranch:
             follow_task_ids_if_false=["branch_2"],
             dag=self.dag,
         )
+        if AIRFLOW_V_3_0_PLUS:
+            self.scheduler_dag = sync_dag_to_db(self.dag)
         self.get_ti(branch_op.task_id).run()
 
     @mock.patch("airflow.providers.common.sql.operators.sql.BaseSQLOperator.get_db_hook")
@@ -1231,7 +1232,7 @@ class TestSqlBranch:
         """Check BranchSQLOperator branch operation"""
         self.branch_1.set_upstream(branch_op)
         self.branch_2.set_upstream(branch_op)
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1241,8 +1242,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1252,7 +1252,6 @@ class TestSqlBranch:
         )
 
         mock_get_records = mock_get_db_hook.return_value.get_first
-
         mock_get_records.return_value = 1
 
         if AIRFLOW_V_3_0_1:
@@ -1282,7 +1281,7 @@ class TestSqlBranch:
         """Check BranchSQLOperator branch operation"""
         self.branch_1.set_upstream(branch_op)
         self.branch_2.set_upstream(branch_op)
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1292,7 +1291,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1330,7 +1329,7 @@ class TestSqlBranch:
         """Check BranchSQLOperator branch operation"""
         self.branch_1.set_upstream(branch_op)
         self.branch_2.set_upstream(branch_op)
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1340,7 +1339,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1350,8 +1349,8 @@ class TestSqlBranch:
         )
 
         mock_get_records = mock_get_db_hook.return_value.get_first
-
         mock_get_records.return_value = false_value
+
         if AIRFLOW_V_3_0_1:
             from airflow.exceptions import DownstreamTasksSkipped
 
@@ -1388,11 +1387,10 @@ class TestSqlBranch:
         self.branch_2.set_upstream(branch_op)
         self.branch_3 = EmptyOperator(task_id="branch_3", dag=self.dag)
         self.branch_3.set_upstream(branch_op)
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
-            self.dag.sync_to_db()
-            SerializedDagModel.write_dag(self.dag, bundle_name="testing")
+            self.scheduler_dag = sync_dag_to_db(self.dag)
             dagrun_kwargs = {
                 "logical_date": DEFAULT_DATE,
                 "run_after": DEFAULT_DATE,
@@ -1400,7 +1398,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1436,7 +1434,7 @@ class TestSqlBranch:
         """Check BranchSQLOperator branch operation"""
         self.branch_1.set_upstream(branch_op)
         self.branch_2.set_upstream(branch_op)
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1446,7 +1444,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        self.dag.create_dagrun(
+        self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1467,7 +1465,7 @@ class TestSqlBranch:
         """Test SQL Branch with skipping all downstream dependencies"""
         branch_op >> self.branch_1 >> self.branch_2
         branch_op >> self.branch_2
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1477,7 +1475,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
@@ -1508,7 +1506,7 @@ class TestSqlBranch:
         """Test skipping downstream dependency for false condition"""
         branch_op >> self.branch_1 >> self.branch_2
         branch_op >> self.branch_2
-        self.dag.clear()
+        self.scheduler_dag.clear()
 
         if AIRFLOW_V_3_0_PLUS:
             dagrun_kwargs = {
@@ -1518,7 +1516,7 @@ class TestSqlBranch:
             }
         else:
             dagrun_kwargs = {"execution_date": DEFAULT_DATE}
-        dr = self.dag.create_dagrun(
+        dr = self.scheduler_dag.create_dagrun(
             run_id="manual__",
             run_type=DagRunType.MANUAL,
             start_date=timezone.utcnow(),
